@@ -37,7 +37,7 @@
 
 #define VERLINES 7							/* number of lines in this vanity text */
 #define VER1 "## dgamelaunch - network console game launcher\n"
-#define VER2 "## version 1.3.3\n"
+#define VER2 "## version 1.3.9\n"
 #define VER3 "## \n"
 #define VER4 "## (c)2001-3 M. Drew Streib. This program's source is released under the GPL.\n"
 #define VER5 "## Send mail to <dtype@dtype.org> for details or a copy of the source code.\n"
@@ -531,6 +531,9 @@ newuser ()
 
 			if (strlen (buf) < 2)
 				error = 1;
+
+			if (strlen (buf) == 0)
+				return;
 		}
 
 	strncpy (my_name, buf, 20);
@@ -587,6 +590,11 @@ newuser ()
 	strncpy (my_email, buf, 80);
 
 	loggedin = 1;
+
+	strcpy (rcfilename, LOC_DGLDIR);
+	strcat (rcfilename, my_name);
+	strcat (rcfilename, ".nethackrc");
+
 	writefile (1);
 }
 
