@@ -129,6 +129,9 @@ ttyread (FILE * fp, Header * h, char **buf, int pread)
 	int counter = 0;
 	long offset;
 
+	/* do this BEFORE header read, hlen bug */
+	offset = ftell (fp);
+
 	if (read_header (fp, h) == 0)
 		{
 			return 0;
@@ -148,7 +151,6 @@ ttyread (FILE * fp, Header * h, char **buf, int pread)
 			exit (1);
 		}
 
-	offset = ftell (fp);
 	if (fread (*buf, 1, h->len, fp) != h->len)
 		{
 			fseek (fp, offset, SEEK_SET);
@@ -175,10 +177,10 @@ ttypread (FILE * fp, Header * h, char **buf, int pread)
 			struct timeval w = { 0, 100000 };
 			select (0, NULL, NULL, NULL, &w);
 			clearerr (fp);
-			if (counter++ > (10 * 60 * 10))
+			if (counter++ > (20 * 60 * 10))
 				{
 					endwin ();
-					printf ("exiting on counter max");
+					printf ("Exiting due to 20 minutes of inactivity.\n");
 					exit (2);
 					return 0;
 				}
